# Babamul basic example notebook

If not set in environmental variables, first create a local `.env` file
by copying `.env.example` and replacing your Babamul credentials.

To run this notebook in JupyterLab, execute:

```sh
uv run jupyter lab
```

or to run in VS Code, first sync the environment so that can be used for
the kernel:

```sh
uv sync
```
